@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.0501';
+our $VERSION = '0.06';
 
 use Moo;
 use strictures 2;
@@ -73,6 +73,12 @@ has pause => (
 );
 
 
+has analyze => (
+    is  => 'ro',
+    isa => \&_invalid_list,
+);
+
+
 has loop => (
     is      => 'ro',
     isa     => \&_invalid_integer,
@@ -108,20 +114,6 @@ has single => (
 );
 
 
-has opus => (
-    is       => 'ro',
-    init_arg => undef,
-    lazy     => 1,
-    builder  => 1,
-);
-
-sub _build_opus {
-    my ($self) = @_;
-    my $opus = MIDI::Opus->new({ from_file => $self->file });
-    return $opus;
-}
-
-
 has score => (
     is       => 'rw',
     init_arg => undef,
@@ -142,18 +134,25 @@ sub process {
     # Counter for the tracks seen
     my $i = 0;
 
+    my $opus = MIDI::Opus->new({ from_file => $self->file });
+
     my $analysis = "Ngram analysis:\n\tNum\tReps\tPhrase\n";
 
     # Handle each track...
-    for my $t ( $self->opus->tracks ) {
+    for my $t ( $opus->tracks ) {
         # Collect the note events for each track except channel 9 (percussion)
         my @events = grep { $_->[0] eq 'note_on' && $_->[2] != 9 && $_->[4] != 0 } $t->events;
 
+        # XXX Assume that there is one channel per track
         my $track_channel = $events[0][2];
 
         # Skip if there are no events and no channel
         next unless @events && defined $track_channel;
 
+        # Skip if this is not a channel to analyze
+        next if $self->analyze && keys @{ $self->analyze }
+            && !grep { $_ == $track_channel } @{ $self->analyze };
+
         $i++;
         $analysis .= "Track $i. Channel: $track_channel\n";
 
@@ -394,7 +393,7 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.0501
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -448,6 +447,10 @@ MIDI output file.  Default: midi-ngram.mid
 
 Insert a rest of the given duration after each phrase.  Default: '' (no resting)
 
+=head2 analyze
+
+ArrayRef of the channels to analyze.  If not given, all channels are analyzed.
+
 =head2 loop
 
 The number of times to choose a weighted phrase.  * Only works with the
@@ -470,11 +473,6 @@ Boolean.  Shuffle the non-weighted phrases before playing them.  Default: 0
 
 Boolean.  Allow single occurrence ngrams.  Default: 0
 
-=head2 opus
-
-The MIDI opus object.  Constructed at runtime.  Constructor argument if given
-will be ignored.
-
 =head2 score
 
 The MIDI score object.  Constructed at runtime.  Constructor argument if given
